==> deepin-draw_5.9.4.orig.tar.xz: deepin-draw-5.9.4/src/widgets/csidewidthwidget.h <==
/*
 * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
 *
 * Author:     Ji XiangLong <jixianglong@uniontech.com>
 *
 * Maintainer: WangYu <wangyu@uniontech.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef CSIDEWIDTHWIDGET_H
#define CSIDEWIDTHWIDGET_H

#include <DFrame>
#include <QHBoxLayout>
#include <DWidget>
#include <DLabel>

DWIDGET_USE_NAMESPACE

//class DMenuComboBox;

class CSideWidthWidget : public DWidget
{
public:
    Q_OBJECT
public:
    explicit CSideWidthWidget(DWidget *parent = nullptr);

//     //更新线宽度函数
//    void updateSideWidth();
    // 更新线宽度函数
    void setSideWidth(int width);
    /*
    * @bref: setMenuNoSelected 设置子菜单未选中
    * @param noSelect
    */
    void setMenuNoSelected(bool noSelect);

signals:
    void signalSideWidthChange();
    void signalSideWidthMenuShow();
    void signalSideWidthChoosed(int width);

    void sideWidthChanged(int width, bool preview = false);

public:
    void changeButtonTheme();

private:
//    DMenuComboBox *m_menuComboBox;// 线宽度选择下拉框
    DComboBox *m_menuComboBox;// 线宽度选择下拉框
    QHBoxLayout *m_layout;// 水平布局器
    quint8 m_comboxHeight; // 下拉框的高度
    DLabel *m_maskLable;

private:
    void initUI();
    void initConnection();

    /*
     * @bref: initLineWidthToCombox 初始化线宽度
    */
    void initLineWidthToCombox();
//    /*
//     * @bref: drawLinePixmap 绘制一张pixmap线
//    */
//    QPixmap drawLinePixmap(int lineWidth, QColor lineColor, int width, int height);
};

#endif // CSIDEWIDTHWIDGET_H

==> deepin-draw_5.11.3.orig.tar.xz: deepin-draw-5.11.3/src/widgets/csidewidthwidget.h <==
/*
 * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
 *
 * Author:     Ji XiangLong <jixianglong@uniontech.com>
 *
 * Maintainer: WangYu <wangyu@uniontech.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef CSIDEWIDTHWIDGET_H
#define CSIDEWIDTHWIDGET_H

#include <DFrame>
#include <QHBoxLayout>
#include <DWidget>
#include <DLabel>

DWIDGET_USE_NAMESPACE

class CSideWidthWidget : public DWidget
{
public:
    Q_OBJECT
public:
    explicit CSideWidthWidget(DWidget *parent = nullptr);

    void setText(const QString &text);

    void setSpace(int space);

    void setWidth(int width);
    QComboBox *menuComboBox();

    QSize sizeHint()const override;

signals:
    void widthChanged(int width, bool preview = false);

public:
    void setVaild(bool vaild);

private:
    QComboBox *m_menuComboBox;// 线宽度选择下拉框
    DLabel *_textLabel = nullptr;
    QHBoxLayout *m_layout;    // 水平布局器
    quint8 m_comboxHeight;    // 下拉框的高度
    DLabel *m_maskLable;

private:
    void initUI();
    void initConnection();

    /*
     * @bref: initLineWidthToCombox 初始化线宽度
    */
    void initLineWidthToCombox();
};

#endif // CSIDEWIDTHWIDGET_H
